@@ -91,16 +91,25 @@ impl W {
         self
     }
 }
-#[doc = "DPORT_CTL\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dport_ctl](index.html) module"]
+#[doc = "DPORT_CTL\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dport_ctl]
+(index.html) module"]
 pub struct DPORT_CTL_SPEC;
 impl crate::RegisterSpec for DPORT_CTL_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [dport_ctl::R](R) reader structure"]
+#[doc = "`read()` method returns [dport_ctl::R]
+(R) reader structure"]
 impl crate::Readable for DPORT_CTL_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [dport_ctl::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [dport_ctl::W]
+(W) writer structure"]
 impl crate::Writable for DPORT_CTL_SPEC {
     type Writer = W;
 }
