@@ -57,7 +57,7 @@ impl<'a> REGISTER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = value as u32;
+        self.w.bits = value;
         self.w
     }
 }
@@ -139,7 +139,7 @@ impl R {
     #[doc = "Bits 0:31"]
     #[inline(always)]
     pub fn register(&self) -> REGISTER_R {
-        REGISTER_R::new(self.bits as u32)
+        REGISTER_R::new(self.bits)
     }
     #[doc = "Bit 0 - Enable the watchdog timer edge interrupt"]
     #[inline(always)]
@@ -175,16 +175,25 @@ impl W {
         self
     }
 }
-#[doc = "EDGE_INT_ENABLE\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [edge_int_enable](index.html) module"]
+#[doc = "EDGE_INT_ENABLE\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [edge_int_enable]
+(index.html) module"]
 pub struct EDGE_INT_ENABLE_SPEC;
 impl crate::RegisterSpec for EDGE_INT_ENABLE_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [edge_int_enable::R](R) reader structure"]
+#[doc = "`read()` method returns [edge_int_enable::R]
+(R) reader structure"]
 impl crate::Readable for EDGE_INT_ENABLE_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [edge_int_enable::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [edge_int_enable::W]
+(W) writer structure"]
 impl crate::Writable for EDGE_INT_ENABLE_SPEC {
     type Writer = W;
 }
