@@ -373,16 +373,25 @@ impl W {
         self
     }
 }
-#[doc = "IO Swap register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ioswap](index.html) module"]
+#[doc = "IO Swap register\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ioswap]
+(index.html) module"]
 pub struct IOSWAP_SPEC;
 impl crate::RegisterSpec for IOSWAP_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [ioswap::R](R) reader structure"]
+#[doc = "`read()` method returns [ioswap::R]
+(R) reader structure"]
 impl crate::Readable for IOSWAP_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [ioswap::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [ioswap::W]
+(W) writer structure"]
 impl crate::Writable for IOSWAP_SPEC {
     type Writer = W;
 }
