@@ -138,16 +138,25 @@ impl W {
         self
     }
 }
-#[doc = "Control where the cache is mapped (unconfirmed)\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_cache_target](index.html) module"]
+#[doc = "Control where the cache is mapped (unconfirmed)\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_cache_target]
+(index.html) module"]
 pub struct SPI_CACHE_TARGET_SPEC;
 impl crate::RegisterSpec for SPI_CACHE_TARGET_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [spi_cache_target::R](R) reader structure"]
+#[doc = "`read()` method returns [spi_cache_target::R]
+(R) reader structure"]
 impl crate::Readable for SPI_CACHE_TARGET_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [spi_cache_target::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [spi_cache_target::W]
+(W) writer structure"]
 impl crate::Writable for SPI_CACHE_TARGET_SPEC {
     type Writer = W;
 }
