@@ -75,12 +75,16 @@ impl R {
         I2S_R::new(((self.bits >> 9) & 0x01) != 0)
     }
 }
-#[doc = "SPI interrupt type register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_interrupt_type](index.html) module"]
+#[doc = "SPI interrupt type register\n\nThis register you can [`read`]
+(crate::generic::Reg::read). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_interrupt_type]
+(index.html) module"]
 pub struct SPI_INTERRUPT_TYPE_SPEC;
 impl crate::RegisterSpec for SPI_INTERRUPT_TYPE_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [spi_interrupt_type::R](R) reader structure"]
+#[doc = "`read()` method returns [spi_interrupt_type::R]
+(R) reader structure"]
 impl crate::Readable for SPI_INTERRUPT_TYPE_SPEC {
     type Reader = R;
 }
