@@ -57,7 +57,7 @@ impl<'a> REGISTER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = value as u32;
+        self.w.bits = value;
         self.w
     }
 }
@@ -65,7 +65,7 @@ impl R {
     #[doc = "Bits 0:31"]
     #[inline(always)]
     pub fn register(&self) -> REGISTER_R {
-        REGISTER_R::new(self.bits as u32)
+        REGISTER_R::new(self.bits)
     }
 }
 impl W {
@@ -81,16 +81,25 @@ impl W {
         self
     }
 }
-#[doc = "EFUSE_DATA1\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [efuse_data1](index.html) module"]
+#[doc = "EFUSE_DATA1\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [efuse_data1]
+(index.html) module"]
 pub struct EFUSE_DATA1_SPEC;
 impl crate::RegisterSpec for EFUSE_DATA1_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [efuse_data1::R](R) reader structure"]
+#[doc = "`read()` method returns [efuse_data1::R]
+(R) reader structure"]
 impl crate::Readable for EFUSE_DATA1_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [efuse_data1::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [efuse_data1::W]
+(W) writer structure"]
 impl crate::Writable for EFUSE_DATA1_SPEC {
     type Writer = W;
 }
