@@ -118,16 +118,25 @@ impl W {
         self
     }
 }
-#[doc = "The values of the strapping pins.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_in](index.html) module"]
+#[doc = "The values of the strapping pins.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_in]
+(index.html) module"]
 pub struct GPIO_IN_SPEC;
 impl crate::RegisterSpec for GPIO_IN_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [gpio_in::R](R) reader structure"]
+#[doc = "`read()` method returns [gpio_in::R]
+(R) reader structure"]
 impl crate::Readable for GPIO_IN_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [gpio_in::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [gpio_in::W]
+(W) writer structure"]
 impl crate::Writable for GPIO_IN_SPEC {
     type Writer = W;
 }
