@@ -417,16 +417,25 @@ impl W {
         self
     }
 }
-#[doc = "GPIO_PIN15\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_pin15](index.html) module"]
+#[doc = "GPIO_PIN15\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_pin15]
+(index.html) module"]
 pub struct GPIO_PIN15_SPEC;
 impl crate::RegisterSpec for GPIO_PIN15_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [gpio_pin15::R](R) reader structure"]
+#[doc = "`read()` method returns [gpio_pin15::R]
+(R) reader structure"]
 impl crate::Readable for GPIO_PIN15_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [gpio_pin15::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [gpio_pin15::W]
+(W) writer structure"]
 impl crate::Writable for GPIO_PIN15_SPEC {
     type Writer = W;
 }
