@@ -128,16 +128,25 @@ impl W {
         self
     }
 }
-#[doc = "Positvie edge of this bit will trigger the RTC-clock-calibration process.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_rtc_calib_sync](index.html) module"]
+#[doc = "Positvie edge of this bit will trigger the RTC-clock-calibration process.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_rtc_calib_sync]
+(index.html) module"]
 pub struct GPIO_RTC_CALIB_SYNC_SPEC;
 impl crate::RegisterSpec for GPIO_RTC_CALIB_SYNC_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [gpio_rtc_calib_sync::R](R) reader structure"]
+#[doc = "`read()` method returns [gpio_rtc_calib_sync::R]
+(R) reader structure"]
 impl crate::Readable for GPIO_RTC_CALIB_SYNC_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [gpio_rtc_calib_sync::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [gpio_rtc_calib_sync::W]
+(W) writer structure"]
 impl crate::Writable for GPIO_RTC_CALIB_SYNC_SPEC {
     type Writer = W;
 }
