@@ -175,16 +175,25 @@ impl W {
         self
     }
 }
-#[doc = "0: during RTC-clock-calibration; 1: RTC-clock-calibration is done\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_rtc_calib_value](index.html) module"]
+#[doc = "0: during RTC-clock-calibration; 1: RTC-clock-calibration is done\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_rtc_calib_value]
+(index.html) module"]
 pub struct GPIO_RTC_CALIB_VALUE_SPEC;
 impl crate::RegisterSpec for GPIO_RTC_CALIB_VALUE_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [gpio_rtc_calib_value::R](R) reader structure"]
+#[doc = "`read()` method returns [gpio_rtc_calib_value::R]
+(R) reader structure"]
 impl crate::Readable for GPIO_RTC_CALIB_VALUE_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [gpio_rtc_calib_value::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [gpio_rtc_calib_value::W]
+(W) writer structure"]
 impl crate::Writable for GPIO_RTC_CALIB_VALUE_SPEC {
     type Writer = W;
 }
