@@ -57,7 +57,7 @@ impl<'a> I2S_I2S_SIGLE_DATA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = value as u32;
+        self.w.bits = value;
         self.w
     }
 }
@@ -65,7 +65,7 @@ impl R {
     #[doc = "Bits 0:31"]
     #[inline(always)]
     pub fn i2s_i2s_sigle_data(&self) -> I2S_I2S_SIGLE_DATA_R {
-        I2S_I2S_SIGLE_DATA_R::new(self.bits as u32)
+        I2S_I2S_SIGLE_DATA_R::new(self.bits)
     }
 }
 impl W {
@@ -81,16 +81,25 @@ impl W {
         self
     }
 }
-#[doc = "I2SCONF_SIGLE_DATA\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [i2sconf_sigle_data](index.html) module"]
+#[doc = "I2SCONF_SIGLE_DATA\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [i2sconf_sigle_data]
+(index.html) module"]
 pub struct I2SCONF_SIGLE_DATA_SPEC;
 impl crate::RegisterSpec for I2SCONF_SIGLE_DATA_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [i2sconf_sigle_data::R](R) reader structure"]
+#[doc = "`read()` method returns [i2sconf_sigle_data::R]
+(R) reader structure"]
 impl crate::Readable for I2SCONF_SIGLE_DATA_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [i2sconf_sigle_data::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [i2sconf_sigle_data::W]
+(W) writer structure"]
 impl crate::Writable for I2SCONF_SIGLE_DATA_SPEC {
     type Writer = W;
 }
