@@ -326,16 +326,25 @@ impl W {
         self
     }
 }
-#[doc = "I2SINT_RAW\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [i2sint_raw](index.html) module"]
+#[doc = "I2SINT_RAW\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [i2sint_raw]
+(index.html) module"]
 pub struct I2SINT_RAW_SPEC;
 impl crate::RegisterSpec for I2SINT_RAW_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [i2sint_raw::R](R) reader structure"]
+#[doc = "`read()` method returns [i2sint_raw::R]
+(R) reader structure"]
 impl crate::Readable for I2SINT_RAW_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [i2sint_raw::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [i2sint_raw::W]
+(W) writer structure"]
 impl crate::Writable for I2SINT_RAW_SPEC {
     type Writer = W;
 }
