@@ -138,16 +138,25 @@ impl W {
         self
     }
 }
-#[doc = "IO_MUX_CONF\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [io_mux_conf](index.html) module"]
+#[doc = "IO_MUX_CONF\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [io_mux_conf]
+(index.html) module"]
 pub struct IO_MUX_CONF_SPEC;
 impl crate::RegisterSpec for IO_MUX_CONF_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [io_mux_conf::R](R) reader structure"]
+#[doc = "`read()` method returns [io_mux_conf::R]
+(R) reader structure"]
 impl crate::Readable for IO_MUX_CONF_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [io_mux_conf::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [io_mux_conf::W]
+(W) writer structure"]
 impl crate::Writable for IO_MUX_CONF_SPEC {
     type Writer = W;
 }
