@@ -57,7 +57,7 @@ impl<'a> REGISTER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = value as u32;
+        self.w.bits = value;
         self.w
     }
 }
@@ -240,7 +240,7 @@ impl R {
     #[doc = "Bits 0:31"]
     #[inline(always)]
     pub fn register(&self) -> REGISTER_R {
-        REGISTER_R::new(self.bits as u32)
+        REGISTER_R::new(self.bits)
     }
     #[doc = "Bits 4:5 - configures IO_MUX function, bottom 2 bits"]
     #[inline(always)]
@@ -306,16 +306,25 @@ impl W {
         self
     }
 }
-#[doc = "IO_MUX_U0TXD\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [io_mux_u0txd](index.html) module"]
+#[doc = "IO_MUX_U0TXD\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [io_mux_u0txd]
+(index.html) module"]
 pub struct IO_MUX_U0TXD_SPEC;
 impl crate::RegisterSpec for IO_MUX_U0TXD_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [io_mux_u0txd::R](R) reader structure"]
+#[doc = "`read()` method returns [io_mux_u0txd::R]
+(R) reader structure"]
 impl crate::Readable for IO_MUX_U0TXD_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [io_mux_u0txd::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [io_mux_u0txd::W]
+(W) writer structure"]
 impl crate::Writable for IO_MUX_U0TXD_SPEC {
     type Writer = W;
 }
