@@ -1,7 +1,7 @@
 #[doc = r"Register block"]
 #[repr(C)]
 pub struct RegisterBlock {
-    _reserved0: [u8; 16usize],
+    _reserved0: [u8; 0x10],
     #[doc = "0x10 - PLL I2C Register"]
     pub pll: crate::Reg<pll::PLL_SPEC>,
 }
