@@ -249,16 +249,25 @@ impl W {
         self
     }
 }
-#[doc = "PLL I2C Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [pll](index.html) module"]
+#[doc = "PLL I2C Register\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [pll]
+(index.html) module"]
 pub struct PLL_SPEC;
 impl crate::RegisterSpec for PLL_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [pll::R](R) reader structure"]
+#[doc = "`read()` method returns [pll::R]
+(R) reader structure"]
 impl crate::Readable for PLL_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [pll::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [pll::W]
+(W) writer structure"]
 impl crate::Writable for PLL_SPEC {
     type Writer = W;
 }
