@@ -551,16 +551,25 @@ impl W {
         self
     }
 }
-#[doc = "SLC_CONF0\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_conf0](index.html) module"]
+#[doc = "SLC_CONF0\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_conf0]
+(index.html) module"]
 pub struct SLC_CONF0_SPEC;
 impl crate::RegisterSpec for SLC_CONF0_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [slc_conf0::R](R) reader structure"]
+#[doc = "`read()` method returns [slc_conf0::R]
+(R) reader structure"]
 impl crate::Readable for SLC_CONF0_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [slc_conf0::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [slc_conf0::W]
+(W) writer structure"]
 impl crate::Writable for SLC_CONF0_SPEC {
     type Writer = W;
 }
