@@ -57,7 +57,7 @@ impl<'a> REGISTER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = value as u32;
+        self.w.bits = value;
         self.w
     }
 }
@@ -65,7 +65,7 @@ impl R {
     #[doc = "Bits 0:31"]
     #[inline(always)]
     pub fn register(&self) -> REGISTER_R {
-        REGISTER_R::new(self.bits as u32)
+        REGISTER_R::new(self.bits)
     }
 }
 impl W {
@@ -81,16 +81,25 @@ impl W {
         self
     }
 }
-#[doc = "SLC_RXLINK_DSCR\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_rxlink_dscr](index.html) module"]
+#[doc = "SLC_RXLINK_DSCR\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_rxlink_dscr]
+(index.html) module"]
 pub struct SLC_RXLINK_DSCR_SPEC;
 impl crate::RegisterSpec for SLC_RXLINK_DSCR_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [slc_rxlink_dscr::R](R) reader structure"]
+#[doc = "`read()` method returns [slc_rxlink_dscr::R]
+(R) reader structure"]
 impl crate::Readable for SLC_RXLINK_DSCR_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [slc_rxlink_dscr::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [slc_rxlink_dscr::W]
+(W) writer structure"]
 impl crate::Writable for SLC_RXLINK_DSCR_SPEC {
     type Writer = W;
 }
