@@ -259,16 +259,25 @@ impl W {
         self
     }
 }
-#[doc = "SLC_TOKEN1\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_token1](index.html) module"]
+#[doc = "SLC_TOKEN1\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_token1]
+(index.html) module"]
 pub struct SLC_TOKEN1_SPEC;
 impl crate::RegisterSpec for SLC_TOKEN1_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [slc_token1::R](R) reader structure"]
+#[doc = "`read()` method returns [slc_token1::R]
+(R) reader structure"]
 impl crate::Readable for SLC_TOKEN1_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [slc_token1::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [slc_token1::W]
+(W) writer structure"]
 impl crate::Writable for SLC_TOKEN1_SPEC {
     type Writer = W;
 }
