@@ -702,16 +702,25 @@ impl W {
         self
     }
 }
-#[doc = "SPI_CTRL\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_ctrl](index.html) module"]
+#[doc = "SPI_CTRL\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_ctrl]
+(index.html) module"]
 pub struct SPI_CTRL_SPEC;
 impl crate::RegisterSpec for SPI_CTRL_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [spi_ctrl::R](R) reader structure"]
+#[doc = "`read()` method returns [spi_ctrl::R]
+(R) reader structure"]
 impl crate::Readable for SPI_CTRL_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [spi_ctrl::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [spi_ctrl::W]
+(W) writer structure"]
 impl crate::Writable for SPI_CTRL_SPEC {
     type Writer = W;
 }
