@@ -474,16 +474,25 @@ impl W {
         self
     }
 }
-#[doc = "In the slave mode, it is the length in bits for \"write-status\" and \"read-status\" operations. The register valueshall be (bit_num-1)\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_slave1](index.html) module"]
+#[doc = "In the slave mode, it is the length in bits for \"write-status\" and \"read-status\" operations. The register valueshall be (bit_num-1)\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_slave1]
+(index.html) module"]
 pub struct SPI_SLAVE1_SPEC;
 impl crate::RegisterSpec for SPI_SLAVE1_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [spi_slave1::R](R) reader structure"]
+#[doc = "`read()` method returns [spi_slave1::R]
+(R) reader structure"]
 impl crate::Readable for SPI_SLAVE1_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [spi_slave1::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [spi_slave1::W]
+(W) writer structure"]
 impl crate::Writable for SPI_SLAVE1_SPEC {
     type Writer = W;
 }
