@@ -57,7 +57,7 @@ impl<'a> SPI_W11_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = value as u32;
+        self.w.bits = value;
         self.w
     }
 }
@@ -65,7 +65,7 @@ impl R {
     #[doc = "Bits 0:31 - the data inside the buffer of the SPI module, word 11"]
     #[inline(always)]
     pub fn spi_w11(&self) -> SPI_W11_R {
-        SPI_W11_R::new(self.bits as u32)
+        SPI_W11_R::new(self.bits)
     }
 }
 impl W {
@@ -81,16 +81,25 @@ impl W {
         self
     }
 }
-#[doc = "the data inside the buffer of the SPI module, word 11\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_w11](index.html) module"]
+#[doc = "the data inside the buffer of the SPI module, word 11\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_w11]
+(index.html) module"]
 pub struct SPI_W11_SPEC;
 impl crate::RegisterSpec for SPI_W11_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [spi_w11::R](R) reader structure"]
+#[doc = "`read()` method returns [spi_w11::R]
+(R) reader structure"]
 impl crate::Readable for SPI_W11_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [spi_w11::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [spi_w11::W]
+(W) writer structure"]
 impl crate::Writable for SPI_W11_SPEC {
     type Writer = W;
 }
