@@ -57,7 +57,7 @@ impl<'a> SLV_WR_STATUS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = value as u32;
+        self.w.bits = value;
         self.w
     }
 }
@@ -65,7 +65,7 @@ impl R {
     #[doc = "Bits 0:31 - In the slave mode, this register are the status register for the master to write into."]
     #[inline(always)]
     pub fn slv_wr_status(&self) -> SLV_WR_STATUS_R {
-        SLV_WR_STATUS_R::new(self.bits as u32)
+        SLV_WR_STATUS_R::new(self.bits)
     }
 }
 impl W {
@@ -81,16 +81,25 @@ impl W {
         self
     }
 }
-#[doc = "In the slave mode, this register are the status register for the master to write into.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_wr_status](index.html) module"]
+#[doc = "In the slave mode, this register are the status register for the master to write into.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_wr_status]
+(index.html) module"]
 pub struct SPI_WR_STATUS_SPEC;
 impl crate::RegisterSpec for SPI_WR_STATUS_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [spi_wr_status::R](R) reader structure"]
+#[doc = "`read()` method returns [spi_wr_status::R]
+(R) reader structure"]
 impl crate::Readable for SPI_WR_STATUS_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [spi_wr_status::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [spi_wr_status::W]
+(W) writer structure"]
 impl crate::Writable for SPI_WR_STATUS_SPEC {
     type Writer = W;
 }
