@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<SPI_CMD_SPEC>> for R {
+impl From<crate::R<SPI_CMD_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<SPI_CMD_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<SPI_CMD_SPEC>> for W {
+impl From<crate::W<SPI_CMD_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<SPI_CMD_SPEC>) -> Self {
         W(writer)
     }
@@ -35,6 +37,7 @@ impl core::convert::From<crate::W<SPI_CMD_SPEC>> for W {
 #[doc = "Field `spi_usr` reader - In the master mode, it is the start bit of a single operation. Self-clear by hardware"]
 pub struct SPI_USR_R(crate::FieldReader<bool, bool>);
 impl SPI_USR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_USR_R(crate::FieldReader::new(bits))
     }
@@ -64,13 +67,14 @@ impl<'a> SPI_USR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
 #[doc = "Field `spi_read` reader - "]
 pub struct SPI_READ_R(crate::FieldReader<bool, bool>);
 impl SPI_READ_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_READ_R(crate::FieldReader::new(bits))
     }
@@ -100,13 +104,14 @@ impl<'a> SPI_READ_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | (((value as u32) & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
         self.w
     }
 }
 #[doc = "Field `spi_write_enable` reader - "]
 pub struct SPI_WRITE_ENABLE_R(crate::FieldReader<bool, bool>);
 impl SPI_WRITE_ENABLE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_WRITE_ENABLE_R(crate::FieldReader::new(bits))
     }
@@ -136,13 +141,14 @@ impl<'a> SPI_WRITE_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | (((value as u32) & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
         self.w
     }
 }
 #[doc = "Field `spi_write_disable` reader - "]
 pub struct SPI_WRITE_DISABLE_R(crate::FieldReader<bool, bool>);
 impl SPI_WRITE_DISABLE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_WRITE_DISABLE_R(crate::FieldReader::new(bits))
     }
@@ -172,13 +178,14 @@ impl<'a> SPI_WRITE_DISABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | (((value as u32) & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
         self.w
     }
 }
 #[doc = "Field `spi_read_id` reader - "]
 pub struct SPI_READ_ID_R(crate::FieldReader<bool, bool>);
 impl SPI_READ_ID_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_READ_ID_R(crate::FieldReader::new(bits))
     }
@@ -208,13 +215,14 @@ impl<'a> SPI_READ_ID_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | (((value as u32) & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
         self.w
     }
 }
 #[doc = "Field `spi_read_sr` reader - "]
 pub struct SPI_READ_SR_R(crate::FieldReader<bool, bool>);
 impl SPI_READ_SR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_READ_SR_R(crate::FieldReader::new(bits))
     }
@@ -244,13 +252,14 @@ impl<'a> SPI_READ_SR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | (((value as u32) & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
         self.w
     }
 }
 #[doc = "Field `spi_write_sr` reader - "]
 pub struct SPI_WRITE_SR_R(crate::FieldReader<bool, bool>);
 impl SPI_WRITE_SR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_WRITE_SR_R(crate::FieldReader::new(bits))
     }
@@ -280,13 +289,14 @@ impl<'a> SPI_WRITE_SR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | (((value as u32) & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
         self.w
     }
 }
 #[doc = "Field `spi_pp` reader - "]
 pub struct SPI_PP_R(crate::FieldReader<bool, bool>);
 impl SPI_PP_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_PP_R(crate::FieldReader::new(bits))
     }
@@ -316,13 +326,14 @@ impl<'a> SPI_PP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | (((value as u32) & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
         self.w
     }
 }
 #[doc = "Field `spi_se` reader - "]
 pub struct SPI_SE_R(crate::FieldReader<bool, bool>);
 impl SPI_SE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_SE_R(crate::FieldReader::new(bits))
     }
@@ -352,13 +363,14 @@ impl<'a> SPI_SE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | (((value as u32) & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
         self.w
     }
 }
 #[doc = "Field `spi_be` reader - "]
 pub struct SPI_BE_R(crate::FieldReader<bool, bool>);
 impl SPI_BE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_BE_R(crate::FieldReader::new(bits))
     }
@@ -388,13 +400,14 @@ impl<'a> SPI_BE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | (((value as u32) & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
         self.w
     }
 }
 #[doc = "Field `spi_ce` reader - "]
 pub struct SPI_CE_R(crate::FieldReader<bool, bool>);
 impl SPI_CE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_CE_R(crate::FieldReader::new(bits))
     }
@@ -424,13 +437,14 @@ impl<'a> SPI_CE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | (((value as u32) & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
         self.w
     }
 }
 #[doc = "Field `spi_dp` reader - "]
 pub struct SPI_DP_R(crate::FieldReader<bool, bool>);
 impl SPI_DP_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_DP_R(crate::FieldReader::new(bits))
     }
@@ -460,13 +474,14 @@ impl<'a> SPI_DP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | (((value as u32) & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
         self.w
     }
 }
 #[doc = "Field `spi_res` reader - "]
 pub struct SPI_RES_R(crate::FieldReader<bool, bool>);
 impl SPI_RES_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_RES_R(crate::FieldReader::new(bits))
     }
@@ -496,13 +511,14 @@ impl<'a> SPI_RES_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | (((value as u32) & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
         self.w
     }
 }
 #[doc = "Field `spi_hpm` reader - "]
 pub struct SPI_HPM_R(crate::FieldReader<bool, bool>);
 impl SPI_HPM_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI_HPM_R(crate::FieldReader::new(bits))
     }
@@ -532,7 +548,7 @@ impl<'a> SPI_HPM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
@@ -680,21 +696,31 @@ impl W {
         SPI_HPM_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
     }
 }
-#[doc = "In the master mode, it is the start bit of a single operation. Self-clear by hardware\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_cmd](index.html) module"]
+#[doc = "In the master mode, it is the start bit of a single operation. Self-clear by hardware\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_cmd]
+(index.html) module"]
 pub struct SPI_CMD_SPEC;
 impl crate::RegisterSpec for SPI_CMD_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [spi_cmd::R](R) reader structure"]
+#[doc = "`read()` method returns [spi_cmd::R]
+(R) reader structure"]
 impl crate::Readable for SPI_CMD_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [spi_cmd::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [spi_cmd::W]
+(W) writer structure"]
 impl crate::Writable for SPI_CMD_SPEC {
     type Writer = W;
 }
