@@ -1078,16 +1078,25 @@ impl W {
         self
     }
 }
-#[doc = "This bit enable the \"command\" phase of an operation.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_user](index.html) module"]
+#[doc = "This bit enable the \"command\" phase of an operation.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_user]
+(index.html) module"]
 pub struct SPI_USER_SPEC;
 impl crate::RegisterSpec for SPI_USER_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [spi_user::R](R) reader structure"]
+#[doc = "`read()` method returns [spi_user::R]
+(R) reader structure"]
 impl crate::Readable for SPI_USER_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [spi_user::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [spi_user::W]
+(W) writer structure"]
 impl crate::Writable for SPI_USER_SPEC {
     type Writer = W;
 }
