@@ -49,7 +49,11 @@ impl core::ops::Deref for FRC1_INT_R {
         &self.0
     }
 }
-#[doc = "Field `frc1_ctrl` reader - bit\\[7\\]: timer enable, bit\\[6\\]: automatically reload, when the counter isequal to zero, bit\\[3:2\\]: prescale-divider, 0: divided by 1, 1: dividedby 16, 2 or 3: divided by 256, bit\\[0\\]: interrupt type, 0:edge, 1:level"]
+#[doc = "Field `frc1_ctrl` reader - bit\\[7\\]
+: timer enable, bit\\[6\\]
+: automatically reload, when the counter isequal to zero, bit\\[3:2\\]
+: prescale-divider, 0: divided by 1, 1: dividedby 16, 2 or 3: divided by 256, bit\\[0\\]
+: interrupt type, 0:edge, 1:level"]
 pub struct FRC1_CTRL_R(crate::FieldReader<u8, u8>);
 impl FRC1_CTRL_R {
     #[inline(always)]
@@ -64,7 +68,11 @@ impl core::ops::Deref for FRC1_CTRL_R {
         &self.0
     }
 }
-#[doc = "Field `frc1_ctrl` writer - bit\\[7\\]: timer enable, bit\\[6\\]: automatically reload, when the counter isequal to zero, bit\\[3:2\\]: prescale-divider, 0: divided by 1, 1: dividedby 16, 2 or 3: divided by 256, bit\\[0\\]: interrupt type, 0:edge, 1:level"]
+#[doc = "Field `frc1_ctrl` writer - bit\\[7\\]
+: timer enable, bit\\[6\\]
+: automatically reload, when the counter isequal to zero, bit\\[3:2\\]
+: prescale-divider, 0: divided by 1, 1: dividedby 16, 2 or 3: divided by 256, bit\\[0\\]
+: interrupt type, 0:edge, 1:level"]
 pub struct FRC1_CTRL_W<'a> {
     w: &'a mut W,
 }
@@ -329,7 +337,11 @@ impl R {
     pub fn frc1_int(&self) -> FRC1_INT_R {
         FRC1_INT_R::new(((self.bits >> 8) & 0x01) != 0)
     }
-    #[doc = "Bits 0:7 - bit\\[7\\]: timer enable, bit\\[6\\]: automatically reload, when the counter isequal to zero, bit\\[3:2\\]: prescale-divider, 0: divided by 1, 1: dividedby 16, 2 or 3: divided by 256, bit\\[0\\]: interrupt type, 0:edge, 1:level"]
+    #[doc = "Bits 0:7 - bit\\[7\\]
+: timer enable, bit\\[6\\]
+: automatically reload, when the counter isequal to zero, bit\\[3:2\\]
+: prescale-divider, 0: divided by 1, 1: dividedby 16, 2 or 3: divided by 256, bit\\[0\\]
+: interrupt type, 0:edge, 1:level"]
     #[inline(always)]
     pub fn frc1_ctrl(&self) -> FRC1_CTRL_R {
         FRC1_CTRL_R::new((self.bits & 0xff) as u8)
@@ -356,7 +368,11 @@ impl R {
     }
 }
 impl W {
-    #[doc = "Bits 0:7 - bit\\[7\\]: timer enable, bit\\[6\\]: automatically reload, when the counter isequal to zero, bit\\[3:2\\]: prescale-divider, 0: divided by 1, 1: dividedby 16, 2 or 3: divided by 256, bit\\[0\\]: interrupt type, 0:edge, 1:level"]
+    #[doc = "Bits 0:7 - bit\\[7\\]
+: timer enable, bit\\[6\\]
+: automatically reload, when the counter isequal to zero, bit\\[3:2\\]
+: prescale-divider, 0: divided by 1, 1: dividedby 16, 2 or 3: divided by 256, bit\\[0\\]
+: interrupt type, 0:edge, 1:level"]
     #[inline(always)]
     pub fn frc1_ctrl(&mut self) -> FRC1_CTRL_W {
         FRC1_CTRL_W { w: self }
@@ -388,16 +404,25 @@ impl W {
         self
     }
 }
-#[doc = "FRC1_CTRL\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc1_ctrl](index.html) module"]
+#[doc = "FRC1_CTRL\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc1_ctrl]
+(index.html) module"]
 pub struct FRC1_CTRL_SPEC;
 impl crate::RegisterSpec for FRC1_CTRL_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [frc1_ctrl::R](R) reader structure"]
+#[doc = "`read()` method returns [frc1_ctrl::R]
+(R) reader structure"]
 impl crate::Readable for FRC1_CTRL_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [frc1_ctrl::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [frc1_ctrl::W]
+(W) writer structure"]
 impl crate::Writable for FRC1_CTRL_SPEC {
     type Writer = W;
 }
