@@ -91,16 +91,25 @@ impl W {
         self
     }
 }
-#[doc = "FRC1_INT\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc1_int](index.html) module"]
+#[doc = "FRC1_INT\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc1_int]
+(index.html) module"]
 pub struct FRC1_INT_SPEC;
 impl crate::RegisterSpec for FRC1_INT_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [frc1_int::R](R) reader structure"]
+#[doc = "`read()` method returns [frc1_int::R]
+(R) reader structure"]
 impl crate::Readable for FRC1_INT_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [frc1_int::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [frc1_int::W]
+(W) writer structure"]
 impl crate::Writable for FRC1_INT_SPEC {
     type Writer = W;
 }
