@@ -175,12 +175,16 @@ impl R {
         RXFIFO_CNT_R::new((self.bits & 0xff) as u8)
     }
 }
-#[doc = "UART STATUS REGISTER\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [uart_status](index.html) module"]
+#[doc = "UART STATUS REGISTER\n\nThis register you can [`read`]
+(crate::generic::Reg::read). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [uart_status]
+(index.html) module"]
 pub struct UART_STATUS_SPEC;
 impl crate::RegisterSpec for UART_STATUS_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [uart_status::R](R) reader structure"]
+#[doc = "`read()` method returns [uart_status::R]
+(R) reader structure"]
 impl crate::Readable for UART_STATUS_SPEC {
     type Reader = R;
 }
