@@ -467,16 +467,25 @@ impl W {
         self
     }
 }
-#[doc = "UART INTERRUPT ENABLE REGISTER\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [uart_int_ena](index.html) module"]
+#[doc = "UART INTERRUPT ENABLE REGISTER\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [uart_int_ena]
+(index.html) module"]
 pub struct UART_INT_ENA_SPEC;
 impl crate::RegisterSpec for UART_INT_ENA_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [uart_int_ena::R](R) reader structure"]
+#[doc = "`read()` method returns [uart_int_ena::R]
+(R) reader structure"]
 impl crate::Readable for UART_INT_ENA_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [uart_int_ena::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [uart_int_ena::W]
+(W) writer structure"]
 impl crate::Writable for UART_INT_ENA_SPEC {
     type Writer = W;
 }
