@@ -42,16 +42,25 @@ impl W {
         self
     }
 }
-#[doc = "Watchdog clock cycle count\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [count](index.html) module"]
+#[doc = "Watchdog clock cycle count\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [count]
+(index.html) module"]
 pub struct COUNT_SPEC;
 impl crate::RegisterSpec for COUNT_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [count::R](R) reader structure"]
+#[doc = "`read()` method returns [count::R]
+(R) reader structure"]
 impl crate::Readable for COUNT_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [count::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [count::W]
+(W) writer structure"]
 impl crate::Writable for COUNT_SPEC {
     type Writer = W;
 }
