@@ -57,7 +57,7 @@ impl<'a> REGISTER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = value as u32;
+        self.w.bits = value;
         self.w
     }
 }
@@ -287,7 +287,7 @@ impl R {
     #[doc = "Bits 0:31"]
     #[inline(always)]
     pub fn register(&self) -> REGISTER_R {
-        REGISTER_R::new(self.bits as u32)
+        REGISTER_R::new(self.bits)
     }
     #[doc = "Bit 0 - Enable the watchdog timer."]
     #[inline(always)]
@@ -363,16 +363,25 @@ impl W {
         self
     }
 }
-#[doc = "WDT_CTL\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [wdt_ctl](index.html) module"]
+#[doc = "WDT_CTL\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [wdt_ctl]
+(index.html) module"]
 pub struct WDT_CTL_SPEC;
 impl crate::RegisterSpec for WDT_CTL_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [wdt_ctl::R](R) reader structure"]
+#[doc = "`read()` method returns [wdt_ctl::R]
+(R) reader structure"]
 impl crate::Readable for WDT_CTL_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [wdt_ctl::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [wdt_ctl::W]
+(W) writer structure"]
 impl crate::Writable for WDT_CTL_SPEC {
     type Writer = W;
 }
